from .DRİVE import Control
from .DRİVE import give
from .DRİVE import info
from .DRİVE import delete
from .DRİVE import get
from .DoIP import IP
from .filesz import EasyDB
from .MultiDB import MultiDB
import .Multidata